

# Label
Hemolgycin

---

## Certification

Bravo!  You have received a Medical Diploma from   
the Orbital Convergence University International Air  
and Water Embassy of the Rusty, Dusty Planet.   

You are now officially clinically certified to  this mixer in your practice.

---

## License
This module may be used for any purpose "friendly", "business",
"government", etc. on topic of the motivations of the GPL 3.0 License.

---

## Summary
Hemoglycin is a dapp for interacting with Aptos.  
 
[https://aptos.dev](https://aptos.dev)   
[https://aptosfoundation.org](https://aptosfoundation.org)   
  
For safe moves, Hemoglycin is feature that is supposed to exist on two types of Beacons,  
A "Howl Beacon" and a "Keys Beacon".

A "Howl Beacon" is essentially a computer that is connected to the internet.  
A "Keys Beacon" is essentially a key chain computer that isn't connected to the internet.   

---

## Howl Beacon Installation 
```
pip install Hemoglycin
```

## Open
```
Hemoglycin ventures on
```

This opens a dapp locally at: 
[http://localhost:22000](http://localhost:22000)


******

## Keys Beacon Installation
The installation steps for the "Keys Beacon" are on at:
[http://localhost:22000/Relatives](http://localhost:22000/Relatives)

******

## Contact
Graceful.Bryonics@Proton.me

